@@ -9,6 +9,7 @@ done
 export RUSTFLAGS='-Zsanitizer=address'
 cargo +nightly test --all-features async_read_utility -- --nocapture
 cargo +nightly test --all-features async_write_utility -- --nocapture
+cargo +nightly test --all-features io_slice_ext -- --nocapture
 
 for _ in $rep; do
     cargo +nightly test --all-features queue -- --nocapture
@@ -26,6 +27,12 @@ done
 
 unset RUSTFLAGS
 export MIRIFLAGS="-Zmiri-disable-isolation"
+
+cargo +nightly miri test \
+    -Z build-std \
+    --target $(uname -m)-unknown-linux-gnu \
+    --all-features io_slice_ext -- --nocapture
+
 exec cargo +nightly miri test \
     -Z build-std \
     --target $(uname -m)-unknown-linux-gnu \
