@@ -1,4 +1,4 @@
-use core::slice;
+use super::IoSliceExt;
 
 use std::io::{self, IoSlice, Result};
 use tokio::io::AsyncWrite;
@@ -45,8 +45,7 @@ pub async fn write_vectored_all<Writer: AsyncWrite + Unpin>(
             }
         }
 
-        let buf = &bufs[0][bytes..];
-        bufs[0] = IoSlice::new(unsafe { slice::from_raw_parts(buf.as_ptr(), buf.len()) });
+        bufs[0] = IoSlice::new(&bufs[0].into_inner()[bytes..]);
     }
 }
 
